@@ -284,6 +284,16 @@ function panel_loader() {
   this.removeAttribute('collapsed');
   this.setAttribute('loadstate','loaded');
   this.parentNode.firstChild.setAttribute('hidden','true');
+
+  if (this.hasAttribute('focusOnLoad')) {
+    var elementToFocus = this.contentDocument.documentElement.getAttribute('elementtofocus');
+    if (elementToFocus) {
+      var element = this.contentDocument.getElementById(elementToFocus);
+      if (element)
+        element.focus();
+    }
+    this.removeAttribute('focusOnLoad');
+  }
 }
 sbPanelList.prototype.update =
 function (force_reload)
@@ -956,6 +966,13 @@ function SidebarSelectPanel(header, should_popopen, should_unhide) {
   }
   if (unhide)  SidebarShowHide();
   if (popopen) SidebarExpandCollapse();
+
+  try { 
+    panel.get_iframe().setAttribute('focusOnLoad', true); 
+  } catch (ex) { 
+    // ignore exception for cases where content isn't built yet
+    // e.g., auto opening search tab: we don't want to focus search field
+  }
   if (!panel.is_selected()) panel.select(false);
 
   return true;
@@ -1141,6 +1158,8 @@ function SidebarShowHide() {
     if (sidebar_box.firstChild != sidebar_panels_splitter) {
       debug("Showing the panels splitter");
       sidebar_panels_splitter.removeAttribute('hidden');
+      if (sidebar_panels_splitter.getAttribute('state') == 'collapsed')
+        sidebar_panels_splitter.removeAttribute('state');
     }
     sidebar_overlay_init();
     sidebar_menu_item.setAttribute('checked', 'true');
