@@ -20,9 +20,9 @@
 
 /*
  *  nsXmlRpcClient XPCOM component
- *  Version: $Revision: 1.24 $
+ *  Version: $Revision: 1.1.1.1 $
  *
- *  $Id: nsXmlRpcClient.js,v 1.24 2002/03/26 07:09:26 samuel%sieb.net Exp $
+ *  $Id: nsXmlRpcClient.js,v 1.1.1.1 2002/08/13 09:42:07 bg135649 Exp $
  */
 
 /*
@@ -91,7 +91,7 @@ nsXmlRpcClient.prototype = {
         // Should we care? POST works only on http and https..
         if (!oURL.scheme) oURL.scheme = 'http';
         if (oURL.scheme != 'http')
-            throw Components.Exceptions('Only HTTP is supported');
+            throw Components.Exception('Only HTTP is supported');
 
         this._serverUrl = oURL;
     },
@@ -360,9 +360,9 @@ nsXmlRpcClient.prototype = {
                     'nsISupportsPRBool');
 
             case this.STRING:
-                uuid.value = Components.interfaces.nsISupportsString
+                uuid.value = Components.interfaces.nsISupportsCString
                 return createInstance(SUPPORTSID + 'string;1',
-                    'nsISupportsString');
+                    'nsISupportsCString');
 
             case this.DOUBLE:
                 uuid.value = Components.interfaces.nsISupportsDouble
@@ -585,7 +585,7 @@ nsXmlRpcClient.prototype = {
         } catch(e) {}
         
         try {
-            obj.QueryInterface(Components.interfaces.nsISupportsString);
+            obj.QueryInterface(Components.interfaces.nsISupportsCString);
             return 'String';
         } catch(e) {}
         
@@ -1285,8 +1285,8 @@ function toScriptableStream(input) {
 /* format a Date object into a iso8601 datetime string, UTC time */
 function iso8601Format(date) {
     var datetime = date.getUTCFullYear();
-    var month = date.getUTCMonth() + 1;
-    datetime += (month < 10 ?  '0' + month : month);
+    var month = String(date.getUTCMonth() + 1);
+    datetime += (month.length == 1 ?  '0' + month : month);
     var day = date.getUTCDate();
     datetime += (day < 10 ? '0' + day : day);
 
