@@ -34,7 +34,6 @@ var msgWindowContractID      = "@mozilla.org/messenger/msgwindow;1";
 
 var messenger;
 var pref;
-var prefServices;
 var statusFeedback;
 var messagePaneController;
 var msgWindow;
@@ -69,8 +68,6 @@ var gPaneConfig = null;
 var gIsEditableMsgFolder = false;
 var gOfflineManager;
 
-// cache the last keywords
-var gLastKeywords = "";
 
 function OnMailWindowUnload()
 {
@@ -78,17 +75,13 @@ function OnMailWindowUnload()
 
   var searchSession = GetSearchSession();
   if (searchSession)
-  {
     removeGlobalListeners();
-    if (gPreQuickSearchView)     //close the cached pre quick search view
-      gPreQuickSearchView.close();
-  }
-  
+
   var dbview = GetDBView();
   if (dbview) {
     dbview.close(); 
   }
-
+    
   var mailSession = Components.classes[mailSessionContractID].getService();
   if(mailSession)
   {
@@ -113,19 +106,13 @@ function OnMailWindowUnload()
 
 }
 
-function CreateMessenger()
-{
-  messenger = Components.classes[messengerContractID].createInstance();
-  messenger = messenger.QueryInterface(Components.interfaces.nsIMessenger);
-}
-
 function CreateMailWindowGlobals()
 {
   // get the messenger instance
-  CreateMessenger();
+  messenger = Components.classes[messengerContractID].createInstance();
+  messenger = messenger.QueryInterface(Components.interfaces.nsIMessenger);
 
-  prefServices = Components.classes[prefContractID].getService(Components.interfaces.nsIPrefService);
-  pref = prefServices.getBranch(null);
+  pref = Components.classes[prefContractID].getService(Components.interfaces.nsIPrefBranch);
 
   //Create windows status feedback
   // set the JS implementation of status feedback before creating the c++ one..
@@ -133,7 +120,7 @@ function CreateMailWindowGlobals()
   // double register the status feedback object as the xul browser window implementation
   window.XULBrowserWindow = window.MsgStatusFeedback;
 
-  statusFeedback = Components.classes[statusFeedbackContractID].createInstance();
+  statusFeedback           = Components.classes[statusFeedbackContractID].createInstance();
   statusFeedback = statusFeedback.QueryInterface(Components.interfaces.nsIMsgStatusFeedback);
 
   /*
@@ -198,49 +185,11 @@ function InitMsgWindow()
   msgWindow.msgHeaderSink = messageHeaderSink;
   msgWindow.SetDOMWindow(window);
   mailSession.AddMsgWindow(msgWindow);
-
-  var messagepane = document.getElementById("messagepane");
-  messagepane.docShell.allowAuth = false;
-  messagepane.addEventListener("click",messagePaneOnClick,true);
-}
-
-function messagePaneOnClick(event)
-{
-  // if this is stand alone mail (no browser)
-  // or this isn't a simple left click, do nothing, and let the normal code execute
-  if (event.button != 0 || event.metaKey || event.ctrlKey || event.shiftKey || event.altKey)
-    return;
-
-  // try to determine the href for what you are clicking on.  
-  // for example, it might be "" if you aren't left clicking on a link
-  var href = hrefForClickEvent(event);
-  if (!href) 
-    return;
-
-  // we know that http://, https://, ftp://, file://, chrome://, 
-  // resource://, about:, and gopher:// (as if), 
-  // should load in a browser.  but if we don't have one of those
-  // (examples are mailto, imap, news, mailbox, snews, nntp, ldap, 
-  // and externally handled schemes like aim)
-  // we may or may not want a browser window, in which case we return here
-  // and let the normal code handle it
-  var needABrowser = /(^http(s)?:|^ftp:|^file:|^gopher:|^chrome:|^resource:|^about:)/i;
-  if (href.search(needABrowser) == -1) 
-    return;
-
-  // if you get here, the user did a simple left click on a link
-  // that we know should be in a browser window.
-  // since we are in the message pane, send it to the top most browser window 
-  // (or open one) right away, instead of waiting for us to get some data and
-  // determine the content type, and then open a browser window
-  openTopBrowserWith(href);
-  // we want to preventDefault, so that in
-  // nsGenericHTMLElement::HandleDOMEventForAnchors(), we don't try to handle the click again
-  event.preventDefault();
 }
 
 function AddDataSources()
 {
+
   accountManagerDataSource = accountManagerDataSource.QueryInterface(Components.interfaces.nsIRDFDataSource);
   folderDataSource = folderDataSource.QueryInterface(Components.interfaces.nsIRDFDataSource);
   //to move menu item
@@ -308,8 +257,8 @@ nsMsgStatusFeedback.prototype =
     {
       if (!this.statusTextFld ) this.statusTextFld = document.getElementById("statusText");
       if (!this.statusBar) this.statusBar = document.getElementById("statusbar-icon");
-      if (!this.throbber)   this.throbber = document.getElementById("navigator-throbber");
-      if (!this.stopCmd)   this.stopCmd = document.getElementById("cmd_stop");
+      if(!this.throbber)   this.throbber = document.getElementById("navigator-throbber");
+      if(!this.stopCmd)   this.stopCmd = document.getElementById("cmd_stop");
     },
 
   // nsIXULBrowserWindow implementation
@@ -326,8 +275,7 @@ nsMsgStatusFeedback.prototype =
   QueryInterface : function(iid)
     {
       if (iid.equals(Components.interfaces.nsIMsgStatusFeedback) ||
-          iid.equals(Components.interfaces.nsIXULBrowserWindow) ||
-          iid.equals(Components.interfaces.nsISupports))
+          iid.equals(Components.interfaces.nsIXULBrowserWindow))
         return this;
       throw Components.results.NS_NOINTERFACE;
     },
@@ -350,20 +298,18 @@ nsMsgStatusFeedback.prototype =
       // Turn progress meter on.
       this.statusBar.setAttribute("mode","undetermined");
 
-      // start the throbber
-      if (this.throbber)
-        this.throbber.setAttribute("busy", true);
+      // turn throbber on
+      this.throbber.setAttribute("busy", true);
 
       //turn on stop button and menu
-      if (this.stopCmd)
-        this.stopCmd.removeAttribute("disabled");
+    this.stopCmd.removeAttribute("disabled");
     },
   startMeteors : function()
     {
       this.pendingStartRequests++;
       // if we don't already have a start meteor timeout pending
       // and the meteors aren't spinning, then kick off a start
-      if (!this.startTimeoutID && !this.meteorsSpinning && window.MsgStatusFeedback)
+      if (!this.startTimeoutID && !this.meteorsSpinning)
         this.startTimeoutID = setTimeout('window.MsgStatusFeedback._startMeteors();', 500);
 
       // since we are going to start up the throbber no sense in processing
@@ -386,16 +332,13 @@ nsMsgStatusFeedback.prototype =
       this.showStatusString(msg);
       defaultStatus = msg;
 
-      // stop the throbber
-      if (this.throbber)
-        this.throbber.setAttribute("busy", false);
+      this.throbber.setAttribute("busy", false);
 
       // Turn progress meter off.
       this.statusBar.setAttribute("mode","normal");
       this.statusBar.value = 0;  // be sure to clear the progress bar
       this.statusBar.label = "";
-      if (this.stopCmd)
-        this.stopCmd.setAttribute("disabled", "true");
+      this.stopCmd.setAttribute("disabled", "true");
 
       this.meteorsSpinning = false;
       this.stopTimeoutID = null;
@@ -416,7 +359,7 @@ nsMsgStatusFeedback.prototype =
       // AND the meteors are currently running then fire a stop timeout to shut them down.
       if (this.pendingStartRequests == 0 && !this.stopTimeoutID)
       {
-        if (this.meteorsSpinning && window.MsgStatusFeedback)
+        if (this.meteorsSpinning)
           this.stopTimeoutID = setTimeout('window.MsgStatusFeedback._stopMeteors();', 500);
       }
   },
@@ -444,14 +387,15 @@ nsMsgWindowCommands.prototype =
 {
   QueryInterface : function(iid)
   {
-    if (iid.equals(Components.interfaces.nsIMsgWindowCommands) ||
-        iid.equals(Components.interfaces.nsISupports))
+    if(iid.equals(Components.interfaces.nsIMsgWindowCommands))
       return this;
     throw Components.results.NS_NOINTERFACE;
+        return null;
   },
   SelectFolder: function(folderUri)
   {
     SelectFolder(folderUri);
+
   },
   SelectMessage: function(messageUri)
   {
@@ -467,10 +411,10 @@ nsMessagePaneController.prototype =
 {
   QueryInterface : function(iid)
   {
-    if (iid.equals(Components.interfaces.nsIMsgMessagePaneController) ||
-        iid.equals(Components.interfaces.nsISupports))
+    if(iid.equals(Components.interfaces.nsIMsgMessagePaneController))
       return this;
     throw Components.results.NS_NOINTERFACE;
+        return null;
   },
   clearMsgPane: function()
   {
@@ -489,9 +433,6 @@ function StopUrls()
 
 function loadStartPage() {
     try {
-        // collapse the junk bar
-        SetUpJunkBar(null);
-
         var startpageenabled = pref.getBoolPref("mailnews.start_page.enabled");
 
         if (startpageenabled) {
@@ -573,10 +514,6 @@ function HideAccountCentral()
             case 1:
                 window.frames["accountCentralPane"].location = "about:blank";
                 accountCentralBox.setAttribute("collapsed", "true");
-                // XXX todo
-                // the code below that always removes the collapsed attribute
-                // makes it so in this pane config, you can't keep the message pane hidden
-                // see bug #188393
                 var messagePaneBox = document.getElementById("messagepanebox");
                 messagePaneBox.removeAttribute("collapsed");
                 var searchAndThreadPaneBox = document.getElementById("searchAndthreadpaneBox");
@@ -604,10 +541,8 @@ function OpenInboxForServer(server)
         var inboxFolder = GetInboxFolder(server);
         SelectFolder(inboxFolder.URI);
 
-        if(CheckOnline()) {
-            if (server.type != "imap")
-                GetMessagesForInboxOnServer(server);
-        }
+        if(CheckOnline())
+            GetMessagesForInboxOnServer(server);
         else {
             var option = PromptGetMessagesOffline();
             if(option == 0) {
@@ -634,93 +569,3 @@ function GetSearchSession()
   else
     return null;
 }
-
-function SetKeywords(aKeywords) 
-{ 
-  // we cache the last keywords.  
-  // if there is no chagne, we do nothing.
-  // most of the time, this will be the case.
-  if (aKeywords == gLastKeywords)
-    return;
-
-  // these are the UI elements who care about keywords
-  var elements = document.getElementsByAttribute("keywordrelated","true");
-  var len = elements.length;
-  for (var i=0; i<len; i++) {
-    var element = elements[i];
-    var originalclass = element.getAttribute("originalclass");
-
-    // we use XBL for certain headers.
-    // if the element has keywordrelated="true"
-    // but no original class, it's an XBL widget
-    // so to get the real element, use getAnonymousElementByAttribute()
-    if (!originalclass) {
-      element = document.getAnonymousElementByAttribute(element, "keywordrelated", "true");
-      originalclass = element.getAttribute("originalclass");
-    }
-
-    if (aKeywords) {
-      if (element.getAttribute("appendoriginalclass") == "true") {
-        aKeywords += " " + originalclass;
-      }
-      element.setAttribute("class", aKeywords);
-    }
-    else {
-      // if no keywords, reset class to the original class
-      element.setAttribute("class", originalclass);
-    }
-  }
-
-  // cache the keywords 
-  gLastKeywords = aKeywords;
-}
-
-function ShowHideToolBarButtons()
-{
-  var prefBase = "mail.toolbars.showbutton.";
-  var prefBranch = prefServices.getBranch(prefBase);
-  var prefCount = {value:0};
-  var prefArray = prefBranch.getChildList("" , prefCount);
-
-  if (prefArray && (prefCount.value > 0)) {
-    for (var i=0;i < prefCount.value;i++) {
-      document.getElementById("button-" + prefArray[i]).hidden = !(prefBranch.getBoolPref(prefArray[i]));
-    }
-  }
-}
-  
-function AddToolBarPrefListener()
-{
-  try {
-    var pbi = pref.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
-    pbi.addObserver(gMailToolBarPrefListener.domain, gMailToolBarPrefListener, false);
-  } catch(ex) {
-    dump("Failed to observe prefs: " + ex + "\n");
-  }
-}
-
-function RemoveToolBarPrefListener()
-{
-  try {
-    var pbi = pref.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
-    pbi.removeObserver(gMailToolBarPrefListener.domain, gMailToolBarPrefListener);
-  } catch(ex) {
-    dump("Failed to remove pref observer: " + ex + "\n");
-  }
-}
-
-// Pref listener constants
-const gMailToolBarPrefListener =
-{
-  domain: "mail.toolbars.showbutton",
-  observe: function(subject, topic, prefName)
-  {
-    // verify that we're changing a button pref
-    if (topic != "nsPref:changed")
-      return;
-
-    document.getElementById("button-" + prefName.substr(this.domain.length+1)).hidden = !(pref.getBoolPref(prefName));
-  }
-};
-
-
